@@ -1,19 +1,11 @@
-import platform
 import shutil
-import subprocess
 import uuid
 from pathlib import Path
-
 import docker
 import validators
 from yaml import load, Loader
-
-from dame._utils import log
 from dame.utils import download_extract_zip, obtain_id, convert_object_to_dict, download_data_file
 
-SINGULARITY_BIN = Path("/usr/bin/singularity")
-SINGULARITY_LOCAL_BIN = Path("/usr/local/bin/singularity")
-
 KEYS_REQUIRED_PARAMETER = {"has_default_value", "position"}
 KEYS_REQUIRED_OUTPUT = {"label", "has_format", "position"}
 KEYS_REQUIRED_INPUT = {"has_fixed_resource"}
@@ -21,45 +13,15 @@ KEYS_REQUIRED_INPUT = {"has_fixed_resource"}
 EXECUTION_DIRECTORY = "executions"
 
 DOCKER_ENGINE = "DOCKER"
-SINGULARITY_ENGINE = "SINGULARITY"
-
-
-def get_singularity():
-    try:
-        if SINGULARITY_BIN.exists():
-            return SINGULARITY_BIN
-        elif SINGULARITY_LOCAL_BIN.exists():
-            return SINGULARITY_LOCAL_BIN
-    except FileNotFoundError:
-        raise FileNotFoundError
 
 
 def get_engine():
-    if platform.system() == 'Linux':
-        try:
-            get_singularity()
-            return SINGULARITY_ENGINE
-        except FileNotFoundError:
-            try:
-                client = docker.from_env()
-                client.info()
-                return DOCKER_ENGINE
-            except Exception as e:
-                raise e
-    elif platform.system() == "Darwin":
-        try:
-            client = docker.from_env()
-            client.info()
-            return DOCKER_ENGINE
-        except Exception as e:
-            raise e
-    elif platform.system() == "Windows":
-        try:
-            client = docker.from_env()
-            client.info()
-            return DOCKER_ENGINE
-        except Exception as e:
-            raise e
+    try:
+        client = docker.from_env()
+        client.info()
+        return DOCKER_ENGINE
+    except Exception as e:
+        raise e
 
 
 def get_file(destination_dir, url, _format):
@@ -97,7 +59,6 @@ def build_input(inputs, destination_dir):
     """
     line = ""
     for _input in inputs:
-        print(_input)
         _input = convert_object_to_dict(_input)
         if not _input.keys() >= KEYS_REQUIRED_INPUT or _input['has_fixed_resource'] is None:
             raise ValueError(f'{_input["id"]} has not a fixedResource')
@@ -223,35 +184,18 @@ def run_docker(component_cmd, execution_dir, component_dir, setup_name, image, v
     res = client.containers.run(command=component_cmd,
                                 image=image,
                                 volumes=volumes,
+                                entrypoint='/bin/bash',
                                 working_dir='/tmp/mint',
                                 detach=True,
-                                entrypoint="/bin/bash",
                                 stream=True,
                                 remove=True
                                 )
     with open(log_file_path, 'wb') as log_file:
         for chunk in res.logs(stream=True):
-            print(chunk)
+            print(chunk.decode('utf-8'))
             log_file.write(chunk)
 
 
-def run_singularity(singularity_cmd, execution_dir, component_dir, setup_name):
-    log_file_path = "{}/output.log".format(execution_dir)
-    with open(log_file_path, 'wb') as log_file:
-        log.info(f'Execution {setup_name} running,  check the logs on {log_file_path}')
-        proc = subprocess.Popen(singularity_cmd, stdout=log_file, stderr=log_file, cwd=component_dir)
-        proc.wait()
-
-
-def get_singularity_cmd(image, setup_cmd_line):
-    try:
-        setup_singularity_bin = get_singularity()
-    except FileNotFoundError as e:
-        raise e
-    setup_singularity_line = "{} exec docker://{}".format(setup_singularity_bin, image)
-    setup_cmd_line = "{} {}".format(setup_singularity_line, setup_cmd_line)
-    return setup_cmd_line.split(' ')
-
 
 def get_docker_cmd(image, setup_cmd_line, mint_volumes):
     volume_line = ""
